/**
 * Copyright (C) 2001-2004
 * - France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors: P. Dechamboux, S. Chassande-Barrioz
 *
 */

package org.objectweb.perseus.jndi;

import org.objectweb.perseus.jndi.ContextImpl;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

/**
 * Naming Manager
 * this singleton class must exist in each jonas server.
 */
public class NamingManager {

    private InitialContext ictx = null;

    private static NamingManager unique = null;

    public static NamingManager getInstance() throws NamingException {
		if (unique == null) 
			unique = new NamingManager();
		return unique;
    }

    /**
     * Create the naming manager.
     * useful to create InitialContext because it may throw an exception.
     */
    private NamingManager() throws NamingException {
		// Create the initial context
		ictx = new InitialContext();
    }

    /**
     * return the initialContext
     */
    public InitialContext getInitialContext() {
		return ictx;
    }

    /**
     * Create a new Context 
     */
    public Context createContext(String namespace) throws NamingException {
		return new ContextImpl(namespace);
    }
	
}
