/**
 * Copyright (C) 2001-2004
 * - France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors: P. Dechamboux, S. Chassande-Barrioz
 *
 */

package org.objectweb.perseus.jndi;

import junit.framework.TestCase;
import org.objectweb.perseus.jndi.PropertiesLoader;

import java.util.Properties;

/**
 *
 */
public class TestPropertiesLoader extends TestCase {
	private static final String PROPFILE = "propfile";
	private static String propertiesFileName = null;
	private static Class contextImpl = null;

	protected PropertiesLoader pl = null;
	
	/**
	 * Constructor in according to the JUnit constraints
	 */
	public TestPropertiesLoader(String tn) {
		super(tn);
	}

	/**
	 * Initialisation sequence executed before each test case.
	 */
	protected void setUp() {
		pl=null;
		propertiesFileName = System.getProperty(PROPFILE);
		contextImpl = ContextImpl.class;
	}

	public void testSimple() {
		pl = new PropertiesLoader();
		try {
			pl.load(propertiesFileName);
		} catch (Exception e) {
			System.out.println(
			"The simple test of PropertiesLoader throws the following error:");
			e.printStackTrace();
			assertTrue(false);
		}
		assertTrue(true);
	}

	public void testPropertiesField() {
		pl = new PropertiesLoader();
		try {
			pl.load(propertiesFileName);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue(false);
		}
		Properties p = pl.getProperties();
		assertNotNull(p);
		assertEquals("1", p.getProperty("Field1"));
		assertEquals("200000", p.getProperty("Field2"));
		assertEquals("azerty", p.getProperty("Field3"));
		assertEquals("0.45", p.getProperty("Field4"));
	}

	public void testContextField() {
		try {
			pl = new PropertiesLoader(contextImpl);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue("The class "+contextImpl+" doesn't be found", false);
		}
		try {
			pl.load(propertiesFileName);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue(false);
		}
		assertNotNull("Unexpected null return from the getContext method",
			pl.getContext());
		try {
			assertTrue("1".equals(pl.getContext().lookup("Field1")));
			assertTrue("200000".equals(pl.getContext().lookup("Field2")));
			assertTrue("azerty".equals(pl.getContext().lookup("Field3")));
			assertTrue("0.45".equals(pl.getContext().lookup("Field4")));
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue("A field is unreachable in context", false);
		}
	}

	public void testInvokeSetters() {
		try {
			pl = new PropertiesLoader(contextImpl);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue("The class "+contextImpl+" doesn't be found", false);
		}
		try {
			pl.load(propertiesFileName);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue(false);
		}
		try {
			pl.invokeSetters(new MyObject());
			assertTrue(true);
		} catch (Exception e) {
			e.printStackTrace();
			assertTrue(e.getMessage(), false);
		}
	}

	private class MyObject {
		public boolean field1set = false;
		public boolean field2set = false;
		public boolean field3set = false;
		public boolean field4set = false;

		public void setField1(Integer i) {
			assertTrue(new Integer(1).equals(i));
			field1set = true;
		}
		public void setField2(Long i) {
			assertTrue(new Long(200000).equals(i));
			field2set = true;
		}
		public void setField3(String s) {
			assertTrue("azerty".equals(s));
			field3set = true;
		}
		public void setField4(Float f) {
			assertTrue(new Float(0.45).equals(f));
			field3set = true;
		}
	}
}
